<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="de" sourcelanguage="">
<context>
    <name></name>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Peter Mattern &lt;a href=&quot;mailto:pmattern@arcor.de&quot;&gt;pmattern@arcor.de&lt;/a&gt;&lt;br/&gt; [de] German translation, Project</source>
        <translation>&lt;p&gt;Peter Mattern &lt;a href=&quot;mailto:pmattern@arcor.de&quot;&gt;pmattern@arcor.de&lt;/a&gt;&lt;br/&gt; [de] Deutsche Übersetzung, Projekt</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Dimitrios Glentadakis &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;&lt;br/&gt; [el] Greek translation</source>
        <translation>&lt;p&gt;Dimitrios Glentadakis &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;&lt;br/&gt; [el] Griechische Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Ozkar L. Garcell &lt;a href=&quot;mailto:ozkar.garcell@gmail.com&quot;&gt;ozkar.garcell@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation</source>
        <translation>&lt;p&gt;Ozkar L. Garcell &lt;a href=&quot;mailto:ozkar.garcell@gmail.com&quot;&gt;ozkar.garcell@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanische Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Laurene Albrand &lt;a href=&quot;mailto:laurenealbrand@outlook.com&quot;&gt;laurenealbrand@outlook.com&lt;/a&gt;&lt;br/&gt; [fr] French translation</source>
        <translation>&lt;p&gt;Laurene Albrand &lt;a href=&quot;mailto:laurenealbrand@outlook.com&quot;&gt;laurenealbrand@outlook.com&lt;/a&gt;&lt;br/&gt; [fr] Französiche Übersetzung</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Rémi Verschelde &lt;a href=&quot;mailto:remi@verschelde.fr&quot;&gt;remi@verschelde.fr&lt;/a&gt;&lt;br/&gt; [fr] French translation, Project</source>
        <translation>&lt;p&gt;Rémi Verschelde &lt;a href=&quot;mailto:remi@verschelde.fr&quot;&gt;remi@verschelde.fr&lt;/a&gt;&lt;br/&gt; [fr] Französiche Übersetzung, Projekt</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Daniel Napora &lt;a href=&quot;mailto:napcok@gmail.com&quot;&gt;napcok@gmail.com&lt;/a&gt;&lt;br/&gt; Tomasz Przybył &lt;a href=&quot;mailto:fademind@gmail.com&quot;&gt;fademind@gmail.com&lt;/a&gt;&lt;br/&gt; [pl] Polish translation</source>
        <translation>&lt;p&gt;Daniel Napora &lt;a href=&quot;mailto:napcok@gmail.com&quot;&gt;napcok@gmail.com&lt;/a&gt;&lt;br/&gt; Tomasz Przybył &lt;a href=&quot;mailto:fademind@gmail.com&quot;&gt;fademind@gmail.com&lt;/a&gt;&lt;br/&gt; [pl] Polnische Übersetzung</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Atilla Öntaş &lt;a href=&quot;mailto:tarakbumba@gmail.com&quot;&gt;tarakbumba@gmail.com&lt;/a&gt;&lt;br/&gt; [tr] Turkish translation</source>
        <translation>&lt;p&gt;Atilla Öntaş &lt;a href=&quot;mailto:tarakbumba@gmail.com&quot;&gt;tarakbumba@gmail.com&lt;/a&gt;&lt;br/&gt; [tr] Türkische Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Yuri Chornoivan &lt;a href=&quot;mailto:yurchor@ukr.net&quot;&gt;yurchor@ukr.net&lt;/a&gt;&lt;br/&gt; [uk] Ukrainian translation</source>
        <translation>&lt;p&gt;Yuri Chornoivan &lt;a href=&quot;mailto:yurchor@ukr.net&quot;&gt;yurchor@ukr.net&lt;/a&gt;&lt;br/&gt; [uk] Ukrainische Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;You-Cheng Hsieh &lt;a href=&quot;mailto:yochenhsieh@gmail.com&quot;&gt;yochenhsieh@gmail.com&lt;/a&gt;&lt;br/&gt; [zh_TW] Chinese (Taiwan) translation</source>
        <translation>&lt;p&gt;You-Cheng Hsieh &lt;a href=&quot;mailto:yochenhsieh@gmail.com&quot;&gt;yochenhsieh@gmail.com&lt;/a&gt;&lt;br/&gt; [zh_TW] Chinesische (Taiwan) Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;pmav99&lt;br/&gt; Project</source>
        <translation>&lt;p&gt;pmav99&lt;br/&gt; Projekt</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Heimen Stoffels &lt;a href=&quot;mailto:vistausss@outlook.com&quot;&gt;vistausss@outlook.com&lt;/a&gt;&lt;br/&gt; [nl] Dutch translation</source>
        <translation>&lt;p&gt;Heimen Stoffels &lt;a href=&quot;mailto:vistausss@outlook.com&quot;&gt;vistausss@outlook.com&lt;/a&gt;&lt;br/&gt; [nl] Niederländische Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;werthad &lt;a href=&quot;mailto:werthad@gmail.com&quot;&gt;werthad@gmail.com&lt;/a&gt;&lt;br/&gt; [hu] Hungarian translation</source>
        <translation>&lt;p&gt;werthad &lt;a href=&quot;mailto:werthad@gmail.com&quot;&gt;werthad@gmail.com&lt;/a&gt;&lt;br/&gt; [hu] Ungarische Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Artem Vorotnikov &lt;a href=&quot;mailto:artem@vorotnikov.me&quot;&gt;artem@vorotnikov.me&lt;/a&gt;&lt;br/&gt; Sergey Shitikov &lt;a href=&quot;mailto:rw4lll@yandex.ru&quot;&gt;rw4lll@yandex.ru&lt;/a&gt;&lt;br/&gt;Alexey Zakaldaev &lt;a href=&quot;mailto:nelex111@gmail.com&quot;&gt;nelex111@gmail.com&lt;/a&gt;&lt;br/&gt;Liliya Panova&lt;br/&gt; [ru] Russian translation</source>
        <translation>&lt;p&gt;Artem Vorotnikov &lt;a href=&quot;mailto:artem@vorotnikov.me&quot;&gt;artem@vorotnikov.me&lt;/a&gt;&lt;br/&gt; Sergey Shitikov &lt;a href=&quot;mailto:rw4lll@yandex.ru&quot;&gt;rw4lll@yandex.ru&lt;/a&gt;&lt;br/&gt;Alexey Zakaldaev &lt;a href=&quot;mailto:nelex111@gmail.com&quot;&gt;nelex111@gmail.com&lt;/a&gt;&lt;br/&gt;Liliya Panova&lt;br/&gt; [ru] Russische Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt; juancarlospaco &lt;a href=&quot;mailto:JuanCarlosPaco@gmail.com&quot;&gt;JuanCarlosPaco@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation, Project</source>
        <translation>&lt;p&gt; juancarlospaco &lt;a href=&quot;mailto:JuanCarlosPaco@gmail.com&quot;&gt;JuanCarlosPaco@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanische Übersetzung, Projekt</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;jose1711 &lt;a href=&quot;mailto:jose1711@gmail.com&quot;&gt;jose1711@gmail.com&lt;/a&gt;&lt;br&gt; [sk] Slovak translation, Project</source>
        <translation>&lt;p&gt;jose1711 &lt;a href=&quot;mailto:jose1711@gmail.com&quot;&gt;jose1711@gmail.com&lt;/a&gt;&lt;br&gt; [sk] Slowakische Übersetzung, Projekt</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Archita Zabaleta &lt;a href=&quot;mailto:architazabaleta@gmail.com&quot;&gt;architazabaleta@gmail.com&lt;/a&gt;&lt;br/&gt; [it] Italian translation</source>
        <translation>&lt;p&gt;Archita Zabaleta &lt;a href=&quot;mailto:architazabaleta@gmail.com&quot;&gt;architazabaleta@gmail.com&lt;/a&gt;&lt;br/&gt; [it] Italienische Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>Jiri Podhorecky&lt;br/&gt;Pavel Fric&lt;br/&gt;[cs] Czech translation</source>
        <translation>Jiri Podhorecky&lt;br/&gt;Pavel Fric&lt;br/&gt;[cs] Tschechische Übersetzung</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Jürgen Thurau &lt;a href=&quot;mailto:linux@psyca.de&quot;&gt;linux@psyca.de&lt;/a&gt;&lt;br/&gt;[de] German translation</source>
        <translation>&lt;p&gt;Jürgen Thurau &lt;a href=&quot;mailto:linux@psyca.de&quot;&gt;linux@psyca.de&lt;/a&gt;&lt;br/&gt;[de] Deutsche Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Masamichi Ito &lt;a href=&quot;https://github.com/ito32bit&quot;&gt;https://github.com/ito32bit&lt;/a&gt;&lt;br/&gt; [ja] Japanese translation</source>
        <translation>&lt;p&gt;Masamichi Ito &lt;a href=&quot;https://github.com/ito32bit&quot;&gt;https://github.com/ito32bit&lt;/a&gt;&lt;br/&gt; [ja] Japanische Übersetzung</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Adrian Moise&lt;a href=&quot;mailto:sah.mat.ro@gmail.com&quot;&gt;sah.mat.ro@gmail.com&lt;/a&gt;&lt;br/&gt; [ro] Romanian translation</source>
        <translation>&lt;p&gt;Adrian Moise&lt;a href=&quot;mailto:sah.mat.ro@gmail.com&quot;&gt;sah.mat.ro@gmail.com&lt;/a&gt;&lt;br/&gt; [ro] Rumänische Übersetzung</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about_dlg.py" line="23"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="24"/>
        <source>Contributors</source>
        <translation>Mitwirkende</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="46"/>
        <source>About Meteo-qt</source>
        <translation>Über Meteo-qt</translation>
    </message>
</context>
<context>
    <name>Action to open the dialog with the weather alerts</name>
    <message>
        <location filename="../meteo_qt.py" line="149"/>
        <source>&amp;Alerts</source>
        <comment>Systray icon context menu</comment>
        <translation>W&amp;arnungen</translation>
    </message>
</context>
<context>
    <name>Action to refresh the weather infos from the server</name>
    <message>
        <location filename="../meteo_qt.py" line="141"/>
        <source>&amp;Refresh</source>
        <comment>Systray icon context menu</comment>
        <translation>Aktualisie&amp;ren</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 1</name>
    <message>
        <location filename="../meteo_qt.py" line="487"/>
        <source>Good</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Gut</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 2</name>
    <message>
        <location filename="../meteo_qt.py" line="492"/>
        <source>Fair</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Angemessen</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 3</name>
    <message>
        <location filename="../meteo_qt.py" line="497"/>
        <source>Moderate</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Mittelmäßig</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 4</name>
    <message>
        <location filename="../meteo_qt.py" line="502"/>
        <source>Poor</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Schlecht</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 5</name>
    <message>
        <location filename="../meteo_qt.py" line="507"/>
        <source>Very Poor</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Sehr schlecht</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 0 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="192"/>
        <source>Sea: Sea like a mirror
Land: Calm. Smoke rises vertically</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Meer wie ein Spiegel
Land: Windstille. Rauch steigt vertikal</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 1 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="197"/>
        <source>Sea: Ripples with the appearance of scales are formed,but without foam crests
Land: Smoke drift indicates wind direction. Leaves and wind vanes are stationary</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Wellen mit auftretenden Schuppen, aber ohne Schaumkämme.
Land: Rauch steigt in Windrichtung. Blätter und Windfahnen bewegen sich nicht.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 10 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="267"/>
        <source>Sea: Very high waves with overhanging crests. Large patches of foam from wave crests give the sea a white appearance. Considerable tumbling of waves with heavy impact. Large amounts of airborne spray reduce visibility
Land: Trees are broken off or uprooted, structural damage likely</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Sehr hohe Wellen mit überschlagenden Wellenkämmen. Große Flächen mit Schaum von Wellenkämmen geben dem Meer eine weißliches Aussehen. Ständig brandende Wellen haben einen großen Einschlag. Eine Menge an in die Luft gewirbelte Gischt reduziert die Sicht.
Land: Bäume brechen ab oder werden entwurzelt. Beschädigungen an Gebäuden möglich.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 11 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="277"/>
        <source>Sea: Exceptionally high waves. Very large patches of foam, driven before the wind, cover much of the sea surface. Very large amounts of airborne spray severely reduce visibility
Land: Widespread vegetation and structural damage likely</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Außergewöhnlich hohe Wellen. Sehr große Flächen an Schaum, bedecken eine große Fläche des Meers. Eine große Menge an Gischt schränkt die Sicht ein.
Land: Größere Flächen der Vegetation und Gebäude können beschädigt werden.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 12 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="285"/>
        <source>Sea: Huge waves. Sea is completely white with foam and spray. Air is filled with driving spray, greatly reducing visibility
Land: Severe widespread damage to vegetation and structures. Debris and unsecured objects are hurled about</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Hohe Wellen. Das Meer ist durch den Schaum und die Gischt vollständig weiß. Die Luft ist erfüllt mit Gischt und schränkt die Sicht stark ein.
Land: Schwere größflächige Beschädigungen an der Vegetation und Gebäuden. Müll und ungesicherte Objekte werden herumgeschleudert.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 2 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="204"/>
        <source>Sea: Small wavelets, still short but more pronounced; crests have a glassy appearance and do not break
Land: Wind felt on exposed skin. Leaves rustle. Wind vanes begin to move</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Kleine Wellen, kurz aber etwas stärker. Wellenkämme haben eine glasige Erscheinung und brechen nicht.
Land: Wind ist auf der Haut spürbar. Blätter rascheln. Windfahnen beginnen sich zu bewegen.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 3 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="212"/>
        <source>Sea: Large wavelets. Crests begin to break; scattered whitecaps
Land: Leaves and small twigs constantly moving, light flags extended</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Große Wellen. Wellenkämme beginnen zu brechen. Vereinzelt Schaumkronen.
Land: Blätter und kleine Äste sind ständig in Bewegung. Leichte Flaggen wehen.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 4 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="219"/>
        <source>Sea: Small waves with breaking crests. Fairly frequent whitecaps
Land: Dust and loose paper raised. Small branches begin to move</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Kleine Wellen mit brechenden Wellenkämme. Häufiger auftretende Schaumkronen.
Land: Staub und loses Papier hebt sich. Schmale Äste fangen an sich zu bewegen.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 5 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="226"/>
        <source>Sea: Moderate waves of some length. Many whitecaps. Small amounts of spray
Land: Branches of a moderate size move. Small trees in leaf begin to sway</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Mäßige Wellen mit gößerer Länge. Viele Schaumkronen. Geringes Auftreten an Gischt.
Land: Geäst mit einer mäßigen Größe bewegt sich. Schmale Bäume beginnen zu Schwanken.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 6 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="233"/>
        <source>Sea: Long waves begin to form. White foam crests are very frequent. Some airborne spray is present
Land: Large branches in motion. Whistling heard in overhead wires. Umbrella use becomes difficult. Empty plastic bins tip over</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Lange Wellen beginnen sich zu formen. Weiße Schaumkronen kommen sehr häufig vor. In die Luft aufspritzende Gischt ist vorhanden.
Land: Großes Geäst ist in Bewegung. Hörbares Pfeifen an Oberleitungen. Verwenden eines Regenschirms wird schwierig. Leere Plastikeimer fallen um.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 7 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="241"/>
        <source>Sea: Sea heaps up. Some foam from breaking waves is blown into streaks along wind direction. Moderate amounts of airborne spray
Land: Whole trees in motion. Effort neededto walk against the wind</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Das Meer türm sich auf. Etwas Schaum durch brechende Wellen werden in Windrichtung geweht. Mäßige Anzahl an fliegender Gischt.
Land: Ganze Bäume sind in Bewegung. Gegen den Wind zu laufen ist anstrengend.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 8 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="249"/>
        <source>Sea: Moderately high waves with breaking crests forming spindrift. Well-marked streaks of foam are blown along wind direction. Considerable airborne spray
Land: Some twigs broken from trees. Cars veer on road. Progress on foot is seriously impeded</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Mäßig hohe Wellen mit brechenden Wellenkämmen verursachen Gischt. Gut sichtbare Streifen an Schaum werden in Windrichtung geblasen. Beträchliche Gischt.
Land: Einige Zweige brechen von Bäumen. Autos schwenken auf Straßen. Vorankommen zu Fuß ist stark eingeschränkt.</translation>
    </message>
</context>
<context>
    <name>Beaufort scale 9 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="258"/>
        <source>Sea: High waves whose crests sometimes roll over. Dense foam is blown along wind direction. Large amounts of airborne spray may begin to reduce visibility
Land: Some branches break off trees, and some small trees blow over. Construction/temporary signs and barricades blow over</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation>Meer: Hohe Wellen, dessen Wellenkämme manchmal umkippen. Dichter Schaum wird in Windrichtung geblasen. Größe Mengen an Gischt reduziert die Sicht.
Land: Einiges Geäst bricht ab und kleine Bäume werden herumgeweht. Konstruktionen/Temporäre Schilder und Absperrungen werden herumgeweht.</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <location filename="../citylistdlg.py" line="53"/>
        <source>&amp;Translate</source>
        <comment>Edit cities name</comment>
        <translation>Überse&amp;tzen</translation>
    </message>
</context>
<context>
    <name>Checkable option to show or not the window at startup</name>
    <message>
        <location filename="../settings.py" line="475"/>
        <source>Start minimized</source>
        <comment>Settings dialogue</comment>
        <translation>Minimiert starten</translation>
    </message>
</context>
<context>
    <name>Checkbox</name>
    <message>
        <location filename="../proxydlg.py" line="49"/>
        <source>Use proxy authentification</source>
        <comment>Proxy settings dialogue</comment>
        <translation>Authentifizierung am Proxy</translation>
    </message>
    <message>
        <location filename="../settings.py" line="425"/>
        <source>Connection by proxy</source>
        <comment>Settings dialogue</comment>
        <translation>Über Proxy verbinden</translation>
    </message>
</context>
<context>
    <name>CityListDlg</name>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Add...</source>
        <translation>Hin&amp;zufügen...</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Remove...</source>
        <translation>Ent&amp;fernen...</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Up</source>
        <translation>Nach &amp;oben</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Down</source>
        <translation>Nach &amp;unten</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>De&amp;fault</source>
        <translation>S&amp;tandard</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Sort</source>
        <translation>alphabetisch &amp;Sortieren</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="139"/>
        <source>The city &quot;{0}&quot; has been removed</source>
        <translation>Die Stadt &quot;{0}&quot; wurde entfernt</translation>
    </message>
</context>
<context>
    <name>Comfort level</name>
    <message>
        <location filename="../meteo_qt.py" line="418"/>
        <source>Comfort</source>
        <comment>Weather overview dialogue</comment>
        <translation>Komfort</translation>
    </message>
</context>
<context>
    <name>Comfort level depending on the dew point</name>
    <message>
        <location filename="../humidex.py" line="32"/>
        <source>Dry</source>
        <comment>Weather info dialogue</comment>
        <translation>Trocken</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="46"/>
        <source>Very comfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Sehr angenehm</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="59"/>
        <source>Comfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Angenehm</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="72"/>
        <source>Alright</source>
        <comment>Weather info dialogue</comment>
        <translation>In Ordnung</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="85"/>
        <source>Uncomfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Unangenehm</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="99"/>
        <source>Very uncomfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Sehr ungemütlich</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="112"/>
        <source>Severely uncomfortable</source>
        <comment>Weather info dialogue</comment>
        <translation>Sehr unangenehm</translation>
    </message>
</context>
<context>
    <name>Comment about the comfort level depending on the dew point</name>
    <message>
        <location filename="../humidex.py" line="46"/>
        <source>Comfort level excellent for exercise</source>
        <comment>ToolTip in weather info dialogue</comment>
        <translation>Ideal fürs Training</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="59"/>
        <source>Hard efforts likely not affected</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation>Erhöhte Anstrengungen haben keine Auswirkungen</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="72"/>
        <source>Expect race times to be slower than in optimal conditions</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation>Erwarten Sie langsamere Rennzeiten als unter normalen Bedingungen</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="85"/>
        <source>Easy training runs might feel OK but difficult to race well or do hard efforts</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation>Einfache Trainingsläufe sind OK, aber Wettrennen und erhöhte Anstrengungen sind schwierig</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="99"/>
        <source>Expect pace to suffer greatly</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation>Erwarten Sie ein stark eingeschränktes Tempo</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="112"/>
        <source>Avoid the exercise. Skip it or dramatically alter goal.
The comfort level is severely uncomfortable and possibly deadly for asthma sufferers</source>
        <comment>ToolTip in weather info dialogue</comment>
        <translation>Vermeide Übungen. Überspringen Sie diese oder verändern Sie deutlich das Ziel.
Das Komfortniveau ist sehr ungemütlich und womöglich tödlich für Asthmatiker</translation>
    </message>
    <message>
        <location filename="../humidex.py" line="32"/>
        <source>The drier air can cause skin to crack and become irritated more easily</source>
        <comment>ToolTip in weather info dialogue</comment>
        <translation>Die trockenere Luft kann zu Hautrissen führen und die Haut schneller reizen</translation>
    </message>
</context>
<context>
    <name>Daylight duration</name>
    <message>
        <location filename="../meteo_qt.py" line="460"/>
        <source>Daylight</source>
        <comment>Weather overview dialogue</comment>
        <translation>Sonnenstunden</translation>
    </message>
</context>
<context>
    <name>Dew point label</name>
    <message>
        <location filename="../meteo_qt.py" line="407"/>
        <source>Dew point</source>
        <comment>Weather overview dialogue</comment>
        <translation>Taupunkt</translation>
    </message>
</context>
<context>
    <name>Entry label for the proxy port</name>
    <message>
        <location filename="../proxydlg.py" line="39"/>
        <source>Port:</source>
        <comment>Proxy settings dialogue</comment>
        <translation>Port:</translation>
    </message>
</context>
<context>
    <name>Entry label for the proxy url</name>
    <message>
        <location filename="../proxydlg.py" line="27"/>
        <source>Proxy URL:</source>
        <comment>Proxy settings dialogue</comment>
        <translation>Proxy-URL:</translation>
    </message>
</context>
<context>
    <name>Extreme UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="182"/>
        <source>Take all precautions: Wear SPF 30+ sunscreen, a long-sleeved
                shirt and trousers,&lt;br/&gt;sunglasses, and a very broad hat.
                Avoid the sun within three hours of solar noon.</source>
        <comment>Extreme https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Ergreifen Sie alle erdenklichen Vorsichtsmaßnahmen:
Verwenden Sie Sonnenschutzmittel mit Lichtschutzfaktor ≥30. Tragen Sie ein langärmeliges Oberteil, lange Hosen, eine Sonnenbrille und Kopfbedeckung mit einem breiten Rand. Vermeiden Sie die Sonne in den drei Stunden um ihren Höchststand.</translation>
    </message>
</context>
<context>
    <name>From the site: Why hPa Is Used - http://n-a-c.biz/WS62694/hPa.htm</name>
    <message>
        <location filename="../conditions.py" line="295"/>
        <source>If the barometric pressure is rising, the weather is improving.
If the barometric pressure is falling, the weather is worsening.
Above 1020 hPa is calm weather/cooler temperatures and below that is unsettled weather/warmer temperatures.
1010-1020 hPa would be weak to normal storms.
990-1010 hPa would be bad storms with possible hurricanes, tornadoes, and typhoons.
Below 990 hPa is the pressure for VERY BAD and POWERFUL hurricanes, tornadoes, and typhoons.</source>
        <comment>Tooltip for the pressure label in weather overview</comment>
        <translation>Wenn der Luftdruck steigt, verbessert sich das Wetter.
Wenn der Luftdruck sinkt, verschlechtert sich das Wetter.
Über 1020 hPa herrscht ruhiges Wetter/kühlere Temperaturen und darunter wird das Wetter unbeständig/wärmere Temperaturen.
1010-1020 hPa wären leichte bis normale Stürme
990-1010 hPa wären schlimme Stürme mit möglichen Hurricanes, Tornados und Taifune.
Unter 990 hPa ist der Druck für SEHR SCHLIMME und STARKE Hurricanes, Tornados und Taifune.</translation>
    </message>
</context>
<context>
    <name>High UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="171"/>
        <source>Cover the body with sun protective clothing, use SPF 30+
                sunscreen,&lt;br/&gt;wear a hat, reduce time in the sun within three
                hours of solar noon, and wear sunglasses.</source>
        <comment>High https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Bedecken Sie den Körper mit vor Sonne schützender Bekleidung und verwenden Sie Sonnenschutzmittel mit Lichtschutzfaktor ≥30. Tragen Sie eine Sonnenbrille und Kopfbedeckung. Minimieren Sie den Aufenthalt in der Sonne in den drei Stunden um ihren Höchststand.</translation>
    </message>
</context>
<context>
    <name>If the temperature will be shown with a decimal or rounded in tray icon</name>
    <message>
        <location filename="../settings.py" line="167"/>
        <source>Temperature accuracy in system tray</source>
        <comment>Settings dialogue</comment>
        <translation>Genauigkeit der Temperaturanzeige in der Leiste</translation>
    </message>
</context>
<context>
    <name>Label before the wind description</name>
    <message>
        <location filename="../meteo_qt.py" line="348"/>
        <source>Wind</source>
        <comment>Weather info panel</comment>
        <translation>Wind</translation>
    </message>
</context>
<context>
    <name>Label for air quality index (air pollution)</name>
    <message>
        <location filename="../meteo_qt.py" line="472"/>
        <source>Air quality</source>
        <comment>Label in weather info dialogue</comment>
        <translation>Luftqualität</translation>
    </message>
</context>
<context>
    <name>Label for the cloudiness (%)</name>
    <message>
        <location filename="../meteo_qt.py" line="363"/>
        <source>Cloudiness</source>
        <comment>Weather info panel</comment>
        <translation>Bewölkung</translation>
    </message>
</context>
<context>
    <name>Label for the humidity (%)</name>
    <message>
        <location filename="../meteo_qt.py" line="385"/>
        <source>Humidity</source>
        <comment>Weather info panel</comment>
        <translation>Luftfeuchtigkeit</translation>
    </message>
</context>
<context>
    <name>Label for the pressure (hPa)</name>
    <message>
        <location filename="../meteo_qt.py" line="374"/>
        <source>Pressure</source>
        <comment>Weather info panel</comment>
        <translation>Luftdruck</translation>
    </message>
</context>
<context>
    <name>Label for the sunrise time (hh:mm)</name>
    <message>
        <location filename="../meteo_qt.py" line="440"/>
        <source>Sunrise</source>
        <comment>Weather info panel</comment>
        <translation>Sonnenaufgang</translation>
    </message>
</context>
<context>
    <name>Label for the sunset (hh:mm)</name>
    <message>
        <location filename="../meteo_qt.py" line="449"/>
        <source>Sunset</source>
        <comment>Weather info panel</comment>
        <translation>Sonnenuntergang</translation>
    </message>
</context>
<context>
    <name>Label of button to open the proxy dialogue</name>
    <message>
        <location filename="../settings.py" line="438"/>
        <source>Settings</source>
        <comment>Settings dialogue</comment>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>Label of the checkbox</name>
    <message>
        <location filename="../settings.py" line="127"/>
        <source>Wind speed unit</source>
        <comment>Settings dialogue</comment>
        <translation>Windgeschwindigkeit in</translation>
    </message>
</context>
<context>
    <name>Link to create a profile in OpenWeatherMap</name>
    <message>
        <location filename="../settings.py" line="455"/>
        <source>&lt;a href=&quot;http://home.openweathermap.org/users/sign_up&quot;&gt;Create key&lt;/a&gt;</source>
        <comment>Settings dialogue</comment>
        <translation>&lt;a href=&quot;http://home.openweathermap.org/users/sign_up&quot;&gt;Schlüssel erstellen&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>Low UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="159"/>
        <source>Wear sunglasses on bright days; use sunscreen if there is
                snow on&lt;br/&gt;the ground, which reflects UV radiation,
                or if you have particularly fair skin.</source>
        <comment>Low https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Tragen Sie an hellen Tagen eine Sonnenbrille. Verwenden Sie Sonnenschutzmittel bei schneebedecktem Grund,der die UV-Strahlung reflektiert, oder wenn Ihre Haut besonders empfindlich ist.</translation>
    </message>
</context>
<context>
    <name>Message when trying to remove thelast and unique city in the list</name>
    <message>
        <location filename="../citylistdlg.py" line="126"/>
        <source>This is the default city!</source>
        <comment>Cities list dialogue</comment>
        <translation>Dies ist die voreingestellte Stadt!</translation>
    </message>
</context>
<context>
    <name>MeteoSettings</name>
    <message>
        <location filename="../settings.py" line="50"/>
        <source>City</source>
        <translation>Stadt</translation>
    </message>
    <message>
        <location filename="../settings.py" line="53"/>
        <source>Click to edit the cities list</source>
        <translation>Klicken zum Bearbeiten der Städteliste</translation>
    </message>
    <message>
        <location filename="../settings.py" line="56"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="../settings.py" line="66"/>
        <source>Bulgarian</source>
        <translation>Bulgarisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="67"/>
        <source>Catalan</source>
        <translation>Katalanisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="68"/>
        <source>Czech</source>
        <translation>Tschechisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="69"/>
        <source>Danish</source>
        <translation>Dänisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="70"/>
        <source>German</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="71"/>
        <source>Greek</source>
        <translation>Griechisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="72"/>
        <source>English</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="73"/>
        <source>Spanish</source>
        <translation>Spanisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="74"/>
        <source>Finnish</source>
        <translation>Finnisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="75"/>
        <source>French</source>
        <translation>Französisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="76"/>
        <source>Hebrew</source>
        <translation>Hebräisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="77"/>
        <source>Croatian</source>
        <translation>Kroatisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="78"/>
        <source>Hungarian</source>
        <translation>Ungarisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="79"/>
        <source>Italian</source>
        <translation>Italienisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="80"/>
        <source>Japanese</source>
        <translation>Japanisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="81"/>
        <source>Lithuanian</source>
        <translation>Litauisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="82"/>
        <source>Norwegian (Bokmaal)</source>
        <translation>Norwegisch (Bokmaal)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="83"/>
        <source>Dutch</source>
        <translation>Niederländisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="84"/>
        <source>Polish</source>
        <translation>Polnisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="85"/>
        <source>Portuguese</source>
        <translation>Portugiesisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="86"/>
        <source>Brazil Portuguese</source>
        <translation>Brasilianisches Portugiesisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="87"/>
        <source>Romanian</source>
        <translation>Rumänisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="88"/>
        <source>Russian</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="89"/>
        <source>Slovak</source>
        <translation>Slowakisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="90"/>
        <source>Swedish</source>
        <translation>Schwedisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="91"/>
        <source>Turkish</source>
        <translation>Türkisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="92"/>
        <source>Ukrainian</source>
        <translation>Ukrainisch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="93"/>
        <source>Chinese Traditional</source>
        <translation>Chinesisch (traditionell)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="94"/>
        <source>Chinese Simplified</source>
        <translation>Chinesisch (vereinfacht)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="113"/>
        <source>Temperature unit</source>
        <translation>Temperatureinheit</translation>
    </message>
    <message>
        <location filename="../settings.py" line="189"/>
        <source>Update interval</source>
        <translation>Aktualisierungsintervall</translation>
    </message>
    <message>
        <location filename="../settings.py" line="190"/>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <location filename="../settings.py" line="213"/>
        <source>Launch at startup</source>
        <translation>Bei Sitzungsbeginn starten</translation>
    </message>
    <message>
        <location filename="../settings.py" line="221"/>
        <source>Font colour in the tray</source>
        <translation>Schriftfarbe in der Systemleiste</translation>
    </message>
    <message>
        <location filename="../settings.py" line="227"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../settings.py" line="228"/>
        <source>Reset font colour to system default</source>
        <translation>Schriftfarbe in der Seitenleiste zurücksetzen</translation>
    </message>
    <message>
        <location filename="../settings.py" line="232"/>
        <source>Notification on weather update</source>
        <translation>Benachrichtigen bei Wetteraktualiserungen</translation>
    </message>
    <message>
        <location filename="../settings.py" line="566"/>
        <source>Meteo-qt Configuration</source>
        <translation>Meteo-qt Konfiguration</translation>
    </message>
</context>
<context>
    <name>Moderate UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="165"/>
        <source>Take precautions, such as covering up, if you will be
                outside.&lt;br/&gt;Stay in shade near midday
                when the sun is strongest.</source>
        <comment>Moderate https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Ergreifen Sie Vorsichtsmaßnahmen wie die Haut bei Aufenthalt im Freien zu bedecken. Bleiben Sie um die Mittagszeit im Schatten.</translation>
    </message>
</context>
<context>
    <name>Option for logging level</name>
    <message>
        <location filename="../settings.py" line="489"/>
        <source>Logging level</source>
        <comment>Settings window</comment>
        <translation>Protokollierungsstufe</translation>
    </message>
</context>
<context>
    <name>Option to choose the default wind speed unit</name>
    <message>
        <location filename="../settings.py" line="136"/>
        <source>Default</source>
        <comment>Settings diaogue</comment>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>Option to choose wind speed unit</name>
    <message>
        <location filename="../settings.py" line="141"/>
        <source>Beaufort</source>
        <comment>Settings dialogue</comment>
        <translation>Beaufort</translation>
    </message>
    <message>
        <location filename="../settings.py" line="146"/>
        <source>Km/h</source>
        <comment>Settings dialogue</comment>
        <translation>Km/h</translation>
    </message>
</context>
<context>
    <name>Precipitation type</name>
    <message>
        <location filename="../conditions.py" line="101"/>
        <source>no</source>
        <comment>Weather overview dialogue</comment>
        <translation>(keiner)</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="103"/>
        <source>rain</source>
        <comment>Weather overview dialogue</comment>
        <translation>Regen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="106"/>
        <source>snow</source>
        <comment>Weather overview dialogue</comment>
        <translation>Schnee</translation>
    </message>
</context>
<context>
    <name>Precipitation type (no/rain/snow)</name>
    <message>
        <location filename="../meteo_qt.py" line="429"/>
        <source>Precipitation</source>
        <comment>Weather overview dialogue</comment>
        <translation>Niederschlag</translation>
    </message>
</context>
<context>
    <name>Proxy password authentification</name>
    <message>
        <location filename="../proxydlg.py" line="68"/>
        <source>Password:</source>
        <comment>Proxy configuration dialogue</comment>
        <translation>Kennwort:</translation>
    </message>
</context>
<context>
    <name>Proxy username authentification</name>
    <message>
        <location filename="../proxydlg.py" line="64"/>
        <source>User ID:</source>
        <comment>Proxy configuration dialogue</comment>
        <translation>Nutzerkennung:</translation>
    </message>
</context>
<context>
    <name>Search by geolocalisation button tooltip</name>
    <message>
        <location filename="../searchcity.py" line="57"/>
        <source>Find my location</source>
        <comment>Automatic search of my place</comment>
        <translation>Finde meinen Standort</translation>
    </message>
</context>
<context>
    <name>Search city</name>
    <message>
        <location filename="../searchcity.py" line="180"/>
        <source>N/A</source>
        <comment>Inserted in search field when the automaticgeolocalisation is not available</comment>
        <translation>N/A</translation>
    </message>
</context>
<context>
    <name>Search city button Tooltip</name>
    <message>
        <location filename="../searchcity.py" line="44"/>
        <source>Search city</source>
        <comment>Search for the given place</comment>
        <translation>Suche Stadt</translation>
    </message>
</context>
<context>
    <name>Search city dialogue</name>
    <message>
        <location filename="../searchcity.py" line="65"/>
        <source>Start typing the city or the ID or the geographic coordinates &quot;latitude, longitude&quot;</source>
        <comment>Default message in the search field</comment>
        <translation>Geben Sie die Stadt, die ID, oder die geografischen Koordinaten ein &quot;Breitengrad, Längengrad&quot;</translation>
    </message>
</context>
<context>
    <name>SearchCity</name>
    <message>
        <location filename="../searchcity.py" line="33"/>
        <source>Searching...</source>
        <translation>Suche...</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="90"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="92"/>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="286"/>
        <source>No results</source>
        <translation>Keine Ergebnisse</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="288"/>
        <source>Found {0} city</source>
        <translation>{0} Stadt gefunden</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="290"/>
        <source>Found {0} cities</source>
        <translation>{0} Städte gefunden</translation>
    </message>
</context>
<context>
    <name>SearchCity window</name>
    <message>
        <location filename="../searchcity.py" line="225"/>
        <source>Please type more than three characters</source>
        <comment>Message in the statusbar</comment>
        <translation>Bitte mehr als drei Zeichen eingeben</translation>
    </message>
</context>
<context>
    <name>Settings dialogue</name>
    <message>
        <location filename="../settings.py" line="249"/>
        <source>Icon &amp; temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Symbol und Temperatur</translation>
    </message>
    <message>
        <location filename="../settings.py" line="254"/>
        <source>Icon</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../settings.py" line="259"/>
        <source>Temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Temperatur</translation>
    </message>
    <message>
        <location filename="../settings.py" line="240"/>
        <source>System tray icon</source>
        <comment>Setting to choose the type of the icon on the tray(only icon only text, icon&amp;text</comment>
        <translation>Systemleisten-Symbol</translation>
    </message>
    <message>
        <location filename="../settings.py" line="264"/>
        <source>Icon &amp; Feels like temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Symbol &amp; gefühlte Temperatur</translation>
    </message>
    <message>
        <location filename="../settings.py" line="269"/>
        <source>Feels like temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>Gefühlte Temperatur</translation>
    </message>
    <message>
        <location filename="../settings.py" line="380"/>
        <source>Toggle tray icon interval</source>
        <comment>Label for the option of the checkbox to activate the toggle of the tray icon and temperature</comment>
        <translation>Symbol in der Systemleiste wechseln</translation>
    </message>
    <message>
        <location filename="../settings.py" line="394"/>
        <source>seconds. Set to 0 to deactivate</source>
        <comment>Label after the spinbox to choose the interval to toggle the tray icon and temperature</comment>
        <translation>Sekunden. 0 zum deaktivieren</translation>
    </message>
    <message>
        <location filename="../settings.py" line="293"/>
        <source>System default</source>
        <comment>ComboBox to choose the system default icons theme</comment>
        <translation>Systemstandard</translation>
    </message>
    <message>
        <location filename="../settings.py" line="299"/>
        <source>Icons theme</source>
        <comment>Tooltip of the ComboBox to choose the icons theme</comment>
        <translation>Symbol-Themen</translation>
    </message>
    <message>
        <location filename="../settings.py" line="410"/>
        <source>Temperature font in system tray</source>
        <comment>Setting for the font size of the temperature in the tray icon</comment>
        <translation>Temperaturanzeige in der Systemleiste</translation>
    </message>
    <message>
        <location filename="../settings.py" line="334"/>
        <source>Tray icon size and text position</source>
        <comment>This option concernes 2 dropdown liststo define the size to initialize the tray iconand the position of the temperature text in the icon</comment>
        <translation>Größe und Position des Systemleisten-Symbol</translation>
    </message>
    <message>
        <location filename="../settings.py" line="343"/>
        <source>Changing this setting you can improve the displaying of the temperature in the tray icon</source>
        <comment>ToolTip of the label &quot;Tray icon size and text position&quot;</comment>
        <translation>Durch Ändern der Einstellung kann die Anzeige der Temperatur im Systemleisten-Symbol verbessert werden</translation>
    </message>
    <message>
        <location filename="../settings.py" line="352"/>
        <source>Tray icon initialization size (default size: 64x64)</source>
        <comment>Tooltip of the drowndrop list with icon sizes</comment>
        <translation>Initialisierungsgröße des Systemleisten-Symbol (Voreinstellung 64x64)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="371"/>
        <source>Temperature position in the icon (vertically) (default value: -12)</source>
        <comment>ToolTip of the widget (a spinbox) to define the position of the temperature paint in the tray icon</comment>
        <translation>Temperaturposition im Symbol (vertikal) (Voreinstellung: -12)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="465"/>
        <source>It is suggested to use a personal key.&lt;br/&gt;If someone hijacks the default meteo-qt key you will not be able to get the weather data (error 401 unauthorized)</source>
        <comment>Tooltip of the api key text field</comment>
        <translation>Es wird empfohlen einen persönlichen Schlüssel zu verwenden.&lt;br/&gt;Falls der vorgegebenen meteo-qt Schlüssel gehijackt wird, werden Sie keine Wetterdaten erhalten (Fehler 401 - nicht autorisiert)</translation>
    </message>
</context>
<context>
    <name>Status bar message</name>
    <message>
        <location filename="../citylistdlg.py" line="95"/>
        <source>The city already exists in the list</source>
        <comment>Cities list dialogue</comment>
        <translation>Die Stadt ist bereits in der Liste enthalten</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="106"/>
        <source>Toggle cities with mouse scroll on the weather window</source>
        <comment>Cities list dialogue</comment>
        <translation>Wechsel zwischen den Städten mit dem Mausrad auf dem Wetterfenster</translation>
    </message>
</context>
<context>
    <name>Status message</name>
    <message>
        <location filename="../searchcity.py" line="116"/>
        <source>Click on &quot;Find my Location&quot; button for automatic geolocation</source>
        <comment>City search dialogue</comment>
        <translation>Klicke auf &quot;Finde meinen Standort&quot; für eine automatische Ortung</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="126"/>
        <source>Put the city&apos;s name, comma, 2-letter country code (ex: London, GB)</source>
        <comment>City search dialogue</comment>
        <translation>Geben Sie den Namen der Stadt, Komma, den 2-stelligen Ländercode (z. B. London, GB) ein</translation>
    </message>
</context>
<context>
    <name>System tray notification</name>
    <message>
        <location filename="../meteo_qt.py" line="2496"/>
        <source>The application has to be restarted to apply the language setting</source>
        <translation>Zur Änderung der Sprache muss die Anwendung neu gestartet werden</translation>
    </message>
</context>
<context>
    <name>SystemTrayIcon</name>
    <message>
        <location filename="../meteo_qt.py" line="127"/>
        <source>Cities</source>
        <translation>Städte</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="140"/>
        <source>&amp;Temporary city</source>
        <translation>&amp;Temporäre Stadt</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="160"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="161"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="162"/>
        <source>Exit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="180"/>
        <source>Searching weather data...</source>
        <translation>Suche Wetterdaten...</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1951"/>
        <source>Empty list</source>
        <translation>Leere Liste</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1970"/>
        <source>No city configured</source>
        <translation>Keine Stadt ausgewählt</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1984"/>
        <source>No city has been configured yet.</source>
        <translation>Es wurde noch keine Stadt ausgewählt.</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1984"/>
        <source>Right click on the icon and click on Settings.</source>
        <translation>Klicke mit der rechten Maustaste auf das Symbol und wähle Einstellungen.</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2564"/>
        <source>Fetching weather data...</source>
        <translation>Rufe Wetterdaten ab...</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2580"/>
        <source>&lt;b&gt;meteo-qt&lt;/b&gt; v{0}
            &lt;br/&gt;License: GPLv3
            &lt;br/&gt;Python {1} - Qt {2} - PyQt {3} on {4}</source>
        <translation>&lt;b&gt;meteo-qt&lt;/b&gt; v{0}
            &lt;br/&gt;Lizenz: GPLv3
            &lt;br/&gt;Python {1} - Qt {2} - PyQt {3} unter {4}</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="200"/>
        <source>Mon</source>
        <translation>Mo</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="201"/>
        <source>Tue</source>
        <translation>Di</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="202"/>
        <source>Wed</source>
        <translation>Mi</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="203"/>
        <source>Thu</source>
        <translation>Do</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="204"/>
        <source>Fri</source>
        <translation>Fr</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="205"/>
        <source>Sat</source>
        <translation>Sa</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="206"/>
        <source>Sun</source>
        <translation>So</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="576"/>
        <source>Weather status</source>
        <translation>Wetterstatus</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1426"/>
        <source>Min Max Temperature of the day</source>
        <translation>Min Max Temparatur des Tages</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2589"/>
        <source>&lt;p&gt;Author: Dimitrios Glentadakis
            &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;
            &lt;p&gt;A simple application showing the weather status
            information on the system tray.
            &lt;p&gt;Website: &lt;a href=&quot;https://github.com/dglent/meteo-qt&quot;&gt;
            https://github.com/dglent/meteo-qt&lt;/a&gt;
            &lt;br/&gt;Data source: &lt;a href=&quot;http://openweathermap.org/&quot;&gt;
            OpenWeatherMap&lt;/a&gt;.
            &lt;br/&gt;This software uses icons from the
            &lt;a href=&quot;http://www.kde.org/&quot;&gt;Oxygen Project&lt;/a&gt;.
            &lt;p&gt;To translate meteo-qt in your language or contribute to
            current translations, you can use the
            &lt;a href=&quot;https://www.transifex.com/projects/p/meteo-qt/&quot;&gt;
            Transifex&lt;/a&gt; platform.
            &lt;p&gt;If you want to report a dysfunction or a suggestion,
            feel free to open an issue in
            &lt;a href=&quot;https://github.com/dglent/meteo-qt/issues&quot;&gt;
            github&lt;/a&gt;.</source>
        <translation>&lt;p&gt;Autor: Dimitrios Glentadakis
            &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;
            &lt;p&gt;Eine einfache Anwendung um die Wetterinformationen
            im Benachrichtigungsfeld anzuzeigen.
            &lt;p&gt;Webseite: &lt;a href=&quot;https://github.com/dglent/meteo-qt&quot;&gt;
            https://github.com/dglent/meteo-qt&lt;/a&gt;
            &lt;br/&gt;Datenquelle: &lt;a href=&quot;http://openweathermap.org/&quot;&gt;
            OpenWeatherMap&lt;/a&gt;.
            &lt;br/&gt;Diese Software verwendet Symbole vom
            &lt;a href=&quot;http://www.kde.org/&quot;&gt;Oxygen Project&lt;/a&gt;.
            &lt;p&gt;Um meteo-qt in Ihre Sprache zu übersetzen oder bei den
            aktuellen Übersetzungen mitzuwirken, können Sie die
            &lt;a href=&quot;https://www.transifex.com/projects/p/meteo-qt/&quot;&gt;
            Transifex&lt;/a&gt; Plattform verwenden.
            &lt;p&gt;Falls Sie eine Fehlfunktion oder eine Anregung melden 
            möchten, können Sie einen Eintrag in
            &lt;a href=&quot;https://github.com/dglent/meteo-qt/issues&quot;&gt;
            github&lt;/a&gt; öffnen.</translation>
    </message>
</context>
<context>
    <name>The Feels Like Temperature</name>
    <message>
        <location filename="../meteo_qt.py" line="181"/>
        <source>Feels like</source>
        <comment>Weather info window</comment>
        <translation>Fühlt sich an wie</translation>
    </message>
</context>
<context>
    <name>The air quality index is not available</name>
    <message>
        <location filename="../meteo_qt.py" line="482"/>
        <source>Unavailable</source>
        <comment>The value in the weather info dialogue</comment>
        <translation>Nicht verfügbar</translation>
    </message>
</context>
<context>
    <name>The key that user can generate in his OpenWeatherMap profile</name>
    <message>
        <location filename="../settings.py" line="448"/>
        <source>OpenWeatherMap key</source>
        <comment>Settings dialogue</comment>
        <translation>Schlüssel von OpenWeatherMap</translation>
    </message>
</context>
<context>
    <name>Tooltip</name>
    <message>
        <location filename="../settings.py" line="58"/>
        <source>The application has to be restared to apply the language setting</source>
        <comment>Settings dialogue</comment>
        <translation>Zur Änderung der Sprache muss die Anwendung neu gestartet werden</translation>
    </message>
</context>
<context>
    <name>Tooltip forcast of the day</name>
    <message>
        <location filename="../meteo_qt.py" line="208"/>
        <source>Probability of precipitation</source>
        <comment>Weather info window</comment>
        <translation>Niederschlagswahrscheinlichkeit</translation>
    </message>
</context>
<context>
    <name>Tooltip of UV label</name>
    <message>
        <location filename="../meteo_qt.py" line="524"/>
        <source>The ultraviolet index at 12 PM</source>
        <comment>Label in weather info dialogue</comment>
        <translation>Der UV-Index um 12 Uhr</translation>
    </message>
</context>
<context>
    <name>Tooltip on weather icon on 6 days forecast</name>
    <message>
        <location filename="../meteo_qt.py" line="1102"/>
        <source>Day</source>
        <comment>Weather information window</comment>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1107"/>
        <source>Morning</source>
        <comment>Weather information window</comment>
        <translation>Morgens</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1112"/>
        <source>Evening</source>
        <comment>Weather information window</comment>
        <translation>Abends</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1117"/>
        <source>Night</source>
        <comment>Weather information window</comment>
        <translation>Nachts</translation>
    </message>
</context>
<context>
    <name>Tootltip forcast of the day</name>
    <message>
        <location filename="../meteo_qt.py" line="1714"/>
        <source>Pressure</source>
        <comment>Weather info window</comment>
        <translation>Druck</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1719"/>
        <source>Humidity</source>
        <comment>Weather info window</comment>
        <translation>Feuchtigkeit</translation>
    </message>
</context>
<context>
    <name>Tray context menu</name>
    <message>
        <location filename="../meteo_qt.py" line="130"/>
        <source>Toggle Window</source>
        <comment>Open/closes the application window</comment>
        <translation>Fenster ein- und ausblenden</translation>
    </message>
</context>
<context>
    <name>Tray icon</name>
    <message>
        <location filename="../meteo_qt.py" line="2092"/>
        <source>Searching for weather data...</source>
        <comment>Tooltip (when mouse over the icon</comment>
        <translation>Suche Wetterdaten...</translation>
    </message>
</context>
<context>
    <name>Tray notification popup</name>
    <message>
        <location filename="../meteo_qt.py" line="68"/>
        <source>&lt;b&gt;Tomorrow:&lt;/b&gt;</source>
        <comment>Title for the weather conditions</comment>
        <translation>&lt;b&gt;Morgen:&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>UV risk</name>
    <message>
        <location filename="../conditions.py" line="146"/>
        <source>Low</source>
        <translation>Schwach</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="148"/>
        <source>Moderate</source>
        <translation>Mäßig</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="151"/>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="153"/>
        <source>Very high</source>
        <translation>Sehr hoch</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="155"/>
        <source>Extreme</source>
        <translation>Extrem</translation>
    </message>
</context>
<context>
    <name>Ultraviolet index</name>
    <message>
        <location filename="../meteo_qt.py" line="515"/>
        <source>UV</source>
        <comment>Label in weather info dialogue</comment>
        <translation>UV</translation>
    </message>
</context>
<context>
    <name>Ultraviolet index waiting text label</name>
    <message>
        <location filename="../meteo_qt.py" line="785"/>
        <source>Fetching...</source>
        <comment>Weather info dialogue</comment>
        <translation>Rufe ab...</translation>
    </message>
</context>
<context>
    <name>Unit displayed after the wind speed value and before
                the wind description (keep the spaces before and after)</name>
    <message>
        <location filename="../meteo_qt.py" line="660"/>
        <source> km/h </source>
        <comment>Weather Infos panel</comment>
        <translation>km/h</translation>
    </message>
</context>
<context>
    <name>Very high UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="177"/>
        <source>Wear SPF 30+ sunscreen, a shirt, sunglasses, and a
                wide-brimmed hat.&lt;br/&gt;Do not stay in the sun for too long.</source>
        <comment>Very high https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>Verwenden Sie Sonnenschutzmittel mit Lichtschutzfaktor ≥30. Tragen Sie ein Oberteil, eine Sonnenbrille und Kopfbedeckung mit breitem Rand. Vermeiden Sie längere Aufenthalte in der Sonne.</translation>
    </message>
</context>
<context>
    <name>Visibility (distance) label</name>
    <message>
        <location filename="../meteo_qt.py" line="396"/>
        <source>Visibility</source>
        <comment>Weather overview dialogue</comment>
        <translation>Sichtbarkeit</translation>
    </message>
</context>
<context>
    <name>Warning message after pressing OK</name>
    <message>
        <location filename="../settings.py" line="560"/>
        <source>Please add a city</source>
        <comment>Settings dialogue</comment>
        <translation>Bitte eine Stadt hinzufügen</translation>
    </message>
</context>
<context>
    <name>Warning message after pressing Ok</name>
    <message>
        <location filename="../settings.py" line="555"/>
        <source>Please enter your OpenWeatherMap key</source>
        <comment>Settings dialogue</comment>
        <translation>Bitte hier den Schlüssel von OpenWeatherMap eintragen</translation>
    </message>
</context>
<context>
    <name>Warning message in dialog status bar</name>
    <message>
        <location filename="../citytranslate.py" line="55"/>
        <source>The city already exist</source>
        <comment>City translation</comment>
        <translation>Diese Stadt ist bereits vorhanden</translation>
    </message>
</context>
<context>
    <name>WeatherConditions</name>
    <message>
        <location filename="../conditions.py" line="8"/>
        <source>thunderstorm with light rain</source>
        <translation>Gewitter mit leichtem Regen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="9"/>
        <source>thunderstorm with rain</source>
        <translation>Gewitter mit Regen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="10"/>
        <source>thunderstorm with heavy rain</source>
        <translation>Gewitter mit starkem Regen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="11"/>
        <source>light thunderstorm</source>
        <translation>leichte Gewitter</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="12"/>
        <source>thunderstorm</source>
        <translation>Gewitter</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="13"/>
        <source>heavy thunderstorm</source>
        <translation>schwere Gewitter</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="14"/>
        <source>ragged thunderstorm</source>
        <translation>einige Gewitter</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="15"/>
        <source>thunderstorm with light drizzle</source>
        <translation>Gewitter mit leichtem Nieselregen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="16"/>
        <source>thunderstorm with drizzle</source>
        <translation>Gewitter mit Nieselregen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="17"/>
        <source>thunderstorm with heavy drizzle</source>
        <translation>Gewitter mit starkem Nieselregen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="18"/>
        <source>light intensity drizzle</source>
        <translation>leichtes Nieseln</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="19"/>
        <source>drizzle</source>
        <translation>Nieseln</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="20"/>
        <source>heavy intensity drizzle</source>
        <translation>starkes Nieseln</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="21"/>
        <source>light intensity drizzle rain</source>
        <translation>leichter Nieselregen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="22"/>
        <source>drizzle rain</source>
        <translation>Nieselregen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="23"/>
        <source>heavy intensity drizzle rain</source>
        <translation>starker Nieselregen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="24"/>
        <source>shower rain and drizzle</source>
        <translation>Regenschauer und Nieseln</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="25"/>
        <source>heavy shower rain and drizzle</source>
        <translation>starke Regenschauer und Nieseln</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="26"/>
        <source>shower drizzle</source>
        <translation>Nieselschauer</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="27"/>
        <source>light rain</source>
        <translation>leichter Regen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="28"/>
        <source>moderate rain</source>
        <translation>mäßiger Regen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="29"/>
        <source>heavy intensity rain</source>
        <translation>starker heftiger Regen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="30"/>
        <source>very heavy rain</source>
        <translation>sehr starker Regen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="31"/>
        <source>extreme rain</source>
        <translation>Starkregen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="32"/>
        <source>freezing rain</source>
        <translation>Eisregen</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="33"/>
        <source>light intensity shower rain</source>
        <translation>leichte Regenschauer</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="34"/>
        <source>shower rain</source>
        <translation>Regenschauer</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="35"/>
        <source>heavy intensity shower rain</source>
        <translation>heftige Regenschauer</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="36"/>
        <source>ragged shower rain</source>
        <translation>einige Regenschauer</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="37"/>
        <source>light snow</source>
        <translation>mäßiger Schnee</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="38"/>
        <source>snow</source>
        <translation>Schnee</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="39"/>
        <source>heavy snow</source>
        <translation>heftiger Schneefall</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="40"/>
        <source>sleet</source>
        <translation>Graupel</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="41"/>
        <source>shower sleet</source>
        <translation>Graupelschauer</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="42"/>
        <source>light rain and snow</source>
        <translation>leichter Regen und Schnee</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="43"/>
        <source>rain and snow</source>
        <translation>Regen und Schnee</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="44"/>
        <source>light shower snow</source>
        <translation>leichter Schneeschauer</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="45"/>
        <source>shower snow</source>
        <translation>Schneeschauer</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="46"/>
        <source>heavy shower snow</source>
        <translation>heftiger Schneeschauer</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="47"/>
        <source>mist</source>
        <translation>trüb</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="48"/>
        <source>smoke</source>
        <translation>Rauch</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="49"/>
        <source>haze</source>
        <translation>Dunst</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="50"/>
        <source>sand, dust whirls</source>
        <translation>Sand, Staubwirbel</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="51"/>
        <source>fog</source>
        <translation>Nebel</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="52"/>
        <source>sand</source>
        <translation>Sand</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="53"/>
        <source>dust</source>
        <translation>Staub</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="54"/>
        <source>volcanic ash</source>
        <translation>vulkanische Asche</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="55"/>
        <source>squalls</source>
        <translation>Böe</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="62"/>
        <source>tornado</source>
        <translation>Tornado</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="57"/>
        <source>clear sky</source>
        <translation>klarer Himmel</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="58"/>
        <source>few clouds</source>
        <translation>ein paar Wolken</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="59"/>
        <source>scattered clouds</source>
        <translation>überwiegend bewölkt</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="60"/>
        <source>broken clouds</source>
        <translation>überwiegend bewölkt</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="61"/>
        <source>overcast clouds</source>
        <translation>wolkenbedeckt</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="63"/>
        <source>tropical storm</source>
        <translation>tropischer Sturm</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="80"/>
        <source>hurricane</source>
        <translation>hurrikan</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="65"/>
        <source>cold</source>
        <translation>kalt</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="66"/>
        <source>hot</source>
        <translation>heiß</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="67"/>
        <source>windy</source>
        <translation>windig</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="68"/>
        <source>hail</source>
        <translation>Hagel</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="69"/>
        <source>calm</source>
        <translation>Still</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="70"/>
        <source>light breeze</source>
        <translation>leichte Brise</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="71"/>
        <source>gentle breeze</source>
        <translation>schwache Brise</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="72"/>
        <source>moderate breeze</source>
        <translation>mäßige Brise</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="73"/>
        <source>fresh breeze</source>
        <translation>frische Brise</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="74"/>
        <source>strong breeze</source>
        <translation>starke Brise</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="75"/>
        <source>high wind, near gale</source>
        <translation>starker Wind, nähe Sturm</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="76"/>
        <source>gale</source>
        <translation>Sturm</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="77"/>
        <source>severe gale</source>
        <translation>starker Sturm</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="78"/>
        <source>storm</source>
        <translation>Sturm</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="79"/>
        <source>violent storm</source>
        <translation>gewaltiger Sturm</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="111"/>
        <source>North</source>
        <translation>Nord</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="112"/>
        <source>NorthEast</source>
        <translation>Nordost</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="113"/>
        <source>North-northeast</source>
        <translation>Nord-Nordost</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="114"/>
        <source>NorthWest</source>
        <translation>Nordwest</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="115"/>
        <source>North-northwest</source>
        <translation>Nord-Nordwest</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="116"/>
        <source>South</source>
        <translation>Süd</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="117"/>
        <source>SouthEast</source>
        <translation>Südost</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="118"/>
        <source>South-southeast</source>
        <translation>Süd-Südost</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="119"/>
        <source>SouthWest</source>
        <translation>Südwest</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="120"/>
        <source>South-southwest</source>
        <translation>Süd-Südwest</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="121"/>
        <source>East</source>
        <translation>Ost</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="122"/>
        <source>East-southeast</source>
        <translation>Ost-Südost</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="123"/>
        <source>East-northeast</source>
        <translation>Ost-Nordost</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="124"/>
        <source>West</source>
        <translation>West</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="125"/>
        <source>West-southwest</source>
        <translation>West-Südwest</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="126"/>
        <source>West-northwest</source>
        <translation>West-Nordwest</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="128"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="129"/>
        <source>NE</source>
        <translation>NO</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="130"/>
        <source>NNE</source>
        <translation>NNO</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="131"/>
        <source>NW</source>
        <translation>NW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="132"/>
        <source>NNW</source>
        <translation>NNW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="133"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="134"/>
        <source>SE</source>
        <translation>SO</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="135"/>
        <source>SSE</source>
        <translation>SSO</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="136"/>
        <source>SW</source>
        <translation>SW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="137"/>
        <source>SSW</source>
        <translation>SSW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="138"/>
        <source>E</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="139"/>
        <source>ESE</source>
        <translation>OSO</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="140"/>
        <source>ENE</source>
        <translation>ONO</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="141"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="142"/>
        <source>WSW</source>
        <translation>WSW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="143"/>
        <source>WNW</source>
        <translation>WNW</translation>
    </message>
</context>
<context>
    <name>Window title</name>
    <message>
        <location filename="../citylistdlg.py" line="67"/>
        <source>Cities</source>
        <comment>Cities list dialogue</comment>
        <translation>Städte</translation>
    </message>
    <message>
        <location filename="../citytranslate.py" line="38"/>
        <source>City translation</source>
        <comment>City translation dialogue</comment>
        <translation>Stadtnamen übersetzen</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="109"/>
        <source>Find a city</source>
        <comment>City search dialogue</comment>
        <translation>Finde eine Stadt</translation>
    </message>
</context>
<context>
    <name>WorkThread</name>
    <message>
        <location filename="../searchcity.py" line="354"/>
        <source>Data error, please try again later
or modify the name of the city</source>
        <translation>Datenfehler, bitte später noch einmal versuchen oder den Namen der Stadt ändern</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="390"/>
        <source>Please wait, searching...</source>
        <translation>Bitte warten, suche...</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="398"/>
        <source>Error: </source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="398"/>
        <source>
Try again later</source>
        <translation>
Bitte versuchen Sie es später noch einmal</translation>
    </message>
</context>
</TS>
